==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_newspost.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_newspost.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("NWSLAN_1", "News story deleted.");
define("NWSLAN_2", "Please tick the confirm box to delete this news item.");
define("NWSLAN_3", "No news items yet.");
define("NWSLAN_4", "Existing News");
define("NWSLAN_5", "Open HTML Editor");
define("NWSLAN_6", "Category");

define("NWSLAN_9", "tick to confirm");
define("NWSLAN_10", "No news categories");
define("NWSLAN_11", "Add/Edit Categories");
define("NWSLAN_12", "Title");
define("NWSLAN_13", "Body");
define("NWSLAN_14", "Extended");
define("NWSLAN_15", "Comments");
// define("NWSLAN_16", "Enabled"); // deprecated see lan_admin.php
// define("NWSLAN_17", "Disabled"); // deprecated see lan_admin.php
define("NWSLAN_18", "Allow comments to be posted to this news item");
define("NWSLAN_19", "Activation");

define("NWSLAN_21", "Activate between");
define("NWSLAN_22", "Visibility");

define("NWSLAN_24", "Preview again");
define("NWSLAN_25", "Update news in database");
define("NWSLAN_26", "Post news to database");
define("NWSLAN_27", "Preview");

define("NWSLAN_29", "News Post");

define("NWSLAN_31", "News item");
define("NWSLAN_32", "deleted");
define("NWSLAN_33", "News Category");
define("NWSLAN_34", "Submitted news item");
define("NWSLAN_35", "News Category Saved");
define("NWSLAN_36", "News Category Updated");
define("NWSLAN_37", "Are you sure you want to delete this category?");
define("NWSLAN_38", "Are you sure you want to delete this submitted news item?");
define("NWSLAN_39", "Are you sure you want to delete this news item?");
define("NWSLAN_40", "Title");

define("NWSLAN_42", "Untitled");
define("NWSLAN_43", "No news items");
define("NWSLAN_44", "News Front Page");
define("NWSLAN_45", "Create News Item");
define("NWSLAN_46", "Categories");
define("NWSLAN_47", "Submitted News");
define("NWSLAN_48", "News Options");
define("NWSLAN_49", "Submitted by");

define("NWSLAN_51", "Existing News Categories");
define("NWSLAN_52", "Category Name");
define("NWSLAN_53", "Category Icon");
define("NWSLAN_54", "View Images");
define("NWSLAN_55", "Update News Category");
define("NWSLAN_56", "Create News Category");
define("NWSLAN_57", "Item");
define("NWSLAN_58", "Post");
define("NWSLAN_59", "No submitted news");
// define("NWSLAN_60", "Submitted News"); //already defined above.

define("NWSLAN_62", "Go to page: ");
define("NWSLAN_63", "Search newsposts");

define("NWSLAN_66", "Upload");
define("NWSLAN_67", "Image");
define("NWSLAN_68", "File");
define("NWSLAN_69", "Upload an image or file for use in the news item");
// define("NWSLAN_70", "The ".e_FILE."downloads folder is not writable, you need to CHMOD 777 the folder before uploading and files.");  // deprecated see lan_admin.php
// define("NWSLAN_71", "The ".e_IMAGE."newspost_images folder is not writable.  You need to CHMOD 777 the folder before uploading any images.");  // deprecated see lan_admin.php
define("NWSLAN_72", "Only show news item between certain dates");
define("NWSLAN_73", "Render type");
define("NWSLAN_74", "Select how and where news item is posted");
define("NWSLAN_75", "Default - post to news page");
define("NWSLAN_76", "Title only - post to news page");
define("NWSLAN_77", "Post to other news menu");

// define("NWSLAN_78", "This option is disabled as file uploading is not enabled on your server");  // deprecated see lan_admin.php
define("NWSLAN_79","Clear Form");

define("NWSLAN_83","Extended news post");
define("NWSLAN_84","Choose which visitors will see news item");

define("NWSLAN_86", "Show News-Category Footer Menu");
define("NWSLAN_87", "News Category Columns?");
define("NWSLAN_88", "News posts to display per page?");
define("NWSLAN_89", "Save News Preferences");
define("NWSLAN_90", "News Preferences");
define("NWSLAN_100", "Enable Image uploading on Submit News page");
define("NWSLAN_101", "Automatic resizing of submitted image");
define("NWSLAN_102", "width in pixels<br /> or leave blank to disable.");
define("NWSLAN_103", "re-post");
define("NWSLAN_104", "by");
define("NWSLAN_105", "Check box to update date stamp of news item to current time");
define("NWSLAN_106", "Submit-News maybe accessed by:");
define("NWSLAN_107", "Enable WYSIWYG editor on Submit-News page.");
define("NWSLAN_108", "on");

define("NWSLAN_111", "Show new date header");
define("NWSLAN_112", "If this box is ticked, a box containing the date will be displayed above news items posted on a new day, useful for distinguishing posts on different days");

define("NWSLAN_113", "Use non-standard template for news layout");
define("NWSLAN_114", "if the theme you're using has a news layout template, use this instead of the generic layout");

define("NWSLAN_115", "News posts to display in archive ?");
define("NWSLAN_116", "First update the preferences with the changed display per page setting, then update again after setting the news archive preference. (0 is un-activated)");
define("NWSLAN_117", "set the title for the news archive");
// define("NWSLAN_118", "View Images"); already defined above.
define("NWSLAN_119", "Settings Saved");
define("NWSLAN_120", "Text to show at the top of Submit News");

define("LAN_NEWS_5", "Error! - Was unable to update news item into database!");
define("LAN_NEWS_6", "News entered into database.");
define("LAN_NEWS_7", "Error! - Was unable to enter news item into database!");
define("LAN_NEWS_9", "Title only is set - <b>only the news title will be shown</b>");
define("LAN_NEWS_10", "This news post is <b>inactive</b> (It will be not shown on front page). ");
define("LAN_NEWS_11", "This news post is <b>active</b> (it will be shown on front page). ");
define("LAN_NEWS_12", "Comments are turned <b>on</b>.");
define("LAN_NEWS_13", "Comments are turned <b>off</b>.");
define("LAN_NEWS_14", "<br />Activation period: ");
define("LAN_NEWS_15", "Body length: ");
define("LAN_NEWS_16", "b. Extended length: ");
define("LAN_NEWS_17", "b.");
define("LAN_NEWS_18", "Info");
define("LAN_NEWS_19",  "Now");
define("LAN_NEWS_21", "News updated in database.");

define("LAN_NEWS_22", "Thumbnail");
define("LAN_NEWS_23", "Choose an image for this news item");
define("LAN_NEWS_24", "Image + Auto-Thumbnail");
define("LAN_NEWS_25", "Auto-Thumbnail size");
define("LAN_NEWS_26", "add new upload");
define("LAN_NEWS_27", "Summary");

define("LAN_NEWS_28", "Sticky");
define("LAN_NEWS_29", "Select if news item will be sticky");
define("LAN_NEWS_30", "If selected, news item will appear above all others");
define("LAN_NEWS_31", "This news post is <b>sticky</b> (it will be shown above all other items). ");
define("LAN_NEWS_32", "Date stamp");
define("LAN_NEWS_33", "Set the date stamp for the current news item");

define("LAN_NEWS_34", "Trackback");
define("LAN_NEWS_35", "Add trackback URLs");
define("LAN_NEWS_36", "<b>Pingback</b> (send a pingback to all URLs in this post)");
define("LAN_NEWS_37", "<b>Trackback URLs:</b> (one URL per line)");
define("LAN_NEWS_38", "Insert images");

define("LAN_NEWS_39", "click on file to insert at cursor position");
define("LAN_NEWS_40", "Insert download links");

define("LAN_NEWS_42", "Files");
// define("LAN_NEWS_43", "(no images in /e107_images/newspost_images)");  // deprecated see lan_admin.php
define("LAN_NEWS_44", "Trackback not enabled.");

define("LAN_NEWS_45", "ID");

define("LAN_NEWS_46", "News item not updated as no changes were made.");
// define("LAN_NEWS_47", "Image");  // already defined above.
define("LAN_NEWS_48", "No Image");

define("LAN_NEWS_49", "Render-type");

define('LAN_NEWS_50', 'Maintenance');
define('LAN_NEWS_51', 'Recalculate comment counts');
define('LAN_NEWS_52', 'Proceed');
define('LAN_NEWS_53', 'Update complete');
define('LAN_NEWS_54', 'News Maintenance');

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_newspost.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_newspost.php $
|     $Revision: 12381 $
|     $Id: lan_newspost.php 12381 2011-11-17 21:14:51Z e107steved $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("NWSLAN_1", "News story deleted.");
define("NWSLAN_2", "Please tick the confirm box to delete this news item.");
define("NWSLAN_3", "No news items yet.");
define("NWSLAN_4", "Existing News");
define("NWSLAN_5", "Open HTML Editor");
define("NWSLAN_6", "Category");

define("NWSLAN_9", "tick to confirm");
define("NWSLAN_10", "No news categories");
define("NWSLAN_11", "Add/Edit Categories");
define("NWSLAN_12", "Title");
define("NWSLAN_13", "Body");
define("NWSLAN_14", "Extended");
define("NWSLAN_15", "Comments");
// define("NWSLAN_16", "Enabled"); // deprecated see lan_admin.php
// define("NWSLAN_17", "Disabled"); // deprecated see lan_admin.php
define("NWSLAN_18", "Allow comments to be posted to this news item");
define("NWSLAN_19", "Activation");

define("NWSLAN_21", "Activate between");
define("NWSLAN_22", "Visibility");

define("NWSLAN_24", "Preview again");
define("NWSLAN_25", "Update news in database");
define("NWSLAN_26", "Post news to database");
define("NWSLAN_27", "Preview");

define("NWSLAN_29", "News Post");

define("NWSLAN_31", "News item");
define("NWSLAN_32", "deleted");
define("NWSLAN_33", "News Category");
define("NWSLAN_34", "Submitted news item");
define("NWSLAN_35", "News Category Saved");
define("NWSLAN_36", "News Category Updated");
define("NWSLAN_37", "Are you sure you want to delete this category?");
define("NWSLAN_38", "Are you sure you want to delete this submitted news item?");
define("NWSLAN_39", "Are you sure you want to delete this news item?");
define("NWSLAN_40", "Title");

define("NWSLAN_42", "Untitled");
define("NWSLAN_43", "No news items");
define("NWSLAN_44", "News Front Page");
define("NWSLAN_45", "Create News Item");
define("NWSLAN_46", "Categories");
define("NWSLAN_47", "Submitted News");
define("NWSLAN_48", "News Options");
define("NWSLAN_49", "Submitted by");

define("NWSLAN_51", "Existing News Categories");
define("NWSLAN_52", "Category Name");
define("NWSLAN_53", "Category Icon");
define("NWSLAN_54", "View Images");
define("NWSLAN_55", "Update News Category");
define("NWSLAN_56", "Create News Category");
define("NWSLAN_57", "Item");
define("NWSLAN_58", "Post");
define("NWSLAN_59", "No submitted news");
// define("NWSLAN_60", "Submitted News"); //already defined above.

define("NWSLAN_62", "Go to page: ");
define("NWSLAN_63", "Search newsposts");

define("NWSLAN_66", "Upload");
define("NWSLAN_67", "Image");
define("NWSLAN_68", "File");
define("NWSLAN_69", "Upload an image or file for use in the news item");
// define("NWSLAN_70", "The ".e_FILE."downloads folder is not writable, you need to CHMOD 777 the folder before uploading and files.");  // deprecated see lan_admin.php
// define("NWSLAN_71", "The ".e_IMAGE."newspost_images folder is not writable.  You need to CHMOD 777 the folder before uploading any images.");  // deprecated see lan_admin.php
define("NWSLAN_72", "Only show news item between certain dates");
define("NWSLAN_73", "Render type");
define("NWSLAN_74", "Select how and where news item is posted");
define("NWSLAN_75", "Default - post to news page");
define("NWSLAN_76", "Title only - post to news page");
define("NWSLAN_77", "Post to other news menu");

// define("NWSLAN_78", "This option is disabled as file uploading is not enabled on your server");  // deprecated see lan_admin.php
define("NWSLAN_79","Clear Form");

define("NWSLAN_83","Extended news post");
define("NWSLAN_84","Choose which visitors will see news item");

define("NWSLAN_86", "Show News-Category Footer Menu");
define("NWSLAN_87", "News Category Columns?");
define("NWSLAN_88", "News posts to display per page?");
define("NWSLAN_89", "Save News Preferences");
define("NWSLAN_90", "News Preferences");
define("NWSLAN_100", "Enable Image uploading on Submit News page");
define("NWSLAN_101", "Automatic resizing of submitted image");
define("NWSLAN_102", "width in pixels<br /> or leave blank to disable.");
define("NWSLAN_103", "re-post");
define("NWSLAN_104", "by");
define("NWSLAN_105", "Check box to update date stamp of news item to current time");
define("NWSLAN_106", "Submit-News maybe accessed by:");
define("NWSLAN_107", "Enable WYSIWYG editor on Submit-News page.");
define("NWSLAN_108", "on");

define("NWSLAN_111", "Show new date header");
define("NWSLAN_112", "If this box is ticked, a box containing the date will be displayed above news items posted on a new day, useful for distinguishing posts on different days");

define("NWSLAN_113", "Use non-standard template for news layout");
define("NWSLAN_114", "if the theme you're using has a news layout template, use this instead of the generic layout");

define("NWSLAN_115", "News posts to display in archive ?");
define("NWSLAN_116", "First update the preferences with the changed display per page setting, then update again after setting the news archive preference. (0 is un-activated)");
define("NWSLAN_117", "set the title for the news archive");
// define("NWSLAN_118", "View Images"); already defined above.
define("NWSLAN_119", "Settings Saved");
define("NWSLAN_120", "Text to show at the top of Submit News");

define("LAN_NEWS_5", "Error! - Was unable to update news item into database!");
define("LAN_NEWS_6", "News entered into database.");
define("LAN_NEWS_7", "Error! - Was unable to enter news item into database!");
define("LAN_NEWS_9", "Title only is set - <b>only the news title will be shown</b>");
define("LAN_NEWS_10", "This news post is <b>inactive</b> (It will be not shown on front page). ");
define("LAN_NEWS_11", "This news post is <b>active</b> (it will be shown on front page). ");
define("LAN_NEWS_12", "Comments are turned <b>on</b>.");
define("LAN_NEWS_13", "Comments are turned <b>off</b>.");
define("LAN_NEWS_14", "<br />Activation period: ");
define("LAN_NEWS_15", "Body length: ");
define("LAN_NEWS_16", "b. Extended length: ");
define("LAN_NEWS_17", "b.");
define("LAN_NEWS_18", "Info");
define("LAN_NEWS_19",  "Now");
define("LAN_NEWS_21", "News updated in database.");

define("LAN_NEWS_22", "Thumbnail");
define("LAN_NEWS_23", "Choose an image for this news item");
define("LAN_NEWS_24", "Image + Auto-Thumbnail");
define("LAN_NEWS_25", "Auto-Thumbnail size");
define("LAN_NEWS_26", "add new upload");
define("LAN_NEWS_27", "Summary");

define("LAN_NEWS_28", "Sticky");
define("LAN_NEWS_29", "Select if news item will be sticky");
define("LAN_NEWS_30", "If selected, news item will appear above all others");
define("LAN_NEWS_31", "This news post is <b>sticky</b> (it will be shown above all other items). ");
define("LAN_NEWS_32", "Date stamp");
define("LAN_NEWS_33", "Set the date stamp for the current news item");

define("LAN_NEWS_34", "Trackback");
define("LAN_NEWS_35", "Add trackback URLs");
define("LAN_NEWS_36", "<b>Pingback</b> (send a pingback to all URLs in this post)");
define("LAN_NEWS_37", "<b>Trackback URLs:</b> (one URL per line)");
define("LAN_NEWS_38", "Insert images");

define("LAN_NEWS_39", "click on file to insert at cursor position");
define("LAN_NEWS_40", "Insert download links");

define("LAN_NEWS_42", "Files");
// define("LAN_NEWS_43", "(no images in /e107_images/newspost_images)");  // deprecated see lan_admin.php
define("LAN_NEWS_44", "Trackback not enabled.");

define("LAN_NEWS_45", "ID");

define("LAN_NEWS_46", "News item not updated as no changes were made.");
// define("LAN_NEWS_47", "Image");  // already defined above.
define("LAN_NEWS_48", "No Image");

define("LAN_NEWS_49", "Render-type");

define('LAN_NEWS_50', 'Maintenance');
define('LAN_NEWS_51', 'Recalculate comment counts');
define('LAN_NEWS_52', 'Proceed');
define('LAN_NEWS_53', 'Update complete - --UPDATE-- comment counts updated, --DELETED-- disallowed comments deleted');
define('LAN_NEWS_54', 'News Maintenance');
define('LAN_NEWS_55', 'Author (Posted by)');
define('LAN_NEWS_56', 'Posted');

// Gap to bring messages into sync with 0.8
define('LAN_NEWS_61', 'Also delete disallowed comments');
define('LAN_NEWS_62', 'Error accessing database, or no news items found');


?>
